@@ -1,5 +1,6 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from . import rowingdata
 from sys import argv
 
 
@@ -7,14 +8,14 @@ def main():
     readFile=argv[1]
 
     try:
-	rowerFile=argv[2]
+        rowerFile=argv[2]
     except IndexError:
-	rowerFile="defaultrower.txt"
+        rowerFile="defaultrower.txt"
 
     rower=rowingdata.getrower(rowerFile)
 
     row=rowingdata.rowingdata(readFile,rowtype="Indoor Rower",
-			    rower=rower)
+                            rower=rower)
 
     rowingdata.copytocb(row.allstats())
 
